@@ -460,6 +460,10 @@ class SabayonInstall:
         if not Entropy.is_sabayon_mce():
             is_sabayon_mce = "0"
 
+        is_sabayon_steambox = "1"
+        if not Entropy.is_sabayon_steambox():
+            is_sabayon_steambox = "0"
+
         # Remove Installer services
         config_script = """\
         rc-update del installer-gui boot default
@@ -494,6 +498,12 @@ class SabayonInstall:
             systemctl --no-reload disable sabayon-mce.service
         fi
 
+        if [ "0" = """+is_sabayon_steambox+""" ]; then
+            rc-update del steambox boot
+            rc-update del steambox default
+            systemctl --no-reload disable steambox.service
+        fi
+
         cd /etc/init.d && ln -s net.lo net.eth0
         """
         self.spawn_chroot(config_script, silent = True)
@@ -602,6 +612,17 @@ module_radeon_args="modeset=1"
             """
             self.spawn_chroot(bb_script, silent = True)
 
+            udev_bl = self._root + "/etc/modprobe.d/bbswitch-blacklist.conf"
+            with open(udev_bl, "w") as bl_f:
+                bl_f.write("""\
+# Added by the Sabayon Installer to avoid a race condition
+# between udev loading nvidia.ko or nouveau.ko and bbswitch,
+# which wants to manage the driver itself.
+blacklist nvidia
+blacklist nouveau
+""")
+
+
     def _get_opengl(self, chroot = None):
         """
         get the current OpenGL subsystem (ati,nvidia,xorg-x11)
